@@ -1,7 +1,7 @@
 """
 This module contains labels for the choices regarding the position of embedding live content
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 CHOICES = (
