@@ -2,7 +2,7 @@ from datetime import date
 
 from django import forms
 from django.utils.text import capfirst
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..custom_filter_form import CustomFilterForm
 from ...constants import feedback_ratings, feedback_read_status
