@@ -7,7 +7,7 @@ import magic
 from django import forms
 from django.conf import settings
 from django.utils import timezone
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from ...constants import allowed_media
 from ...models import MediaFile
