@@ -3,7 +3,7 @@ import logging
 from django import forms
 from django.contrib.auth import get_user_model
 from django.db.models import Q
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ...constants import mirrored_page_first, position
 from ...models import Page, Region
