@@ -1,7 +1,7 @@
 import logging
 
 from django.contrib import messages
-from django.utils.translation import override, ugettext_lazy as _
+from django.utils.translation import override, gettext_lazy as _
 
 from ..custom_model_form import CustomModelForm
 from ...constants import push_notifications
