@@ -7,7 +7,7 @@ from zoneinfo import available_timezones
 from django import forms
 from django.conf import settings
 from django.db.models import Q
-from django.utils.translation import override, ugettext_lazy as _
+from django.utils.translation import override, gettext_lazy as _
 from django.apps import apps
 
 from linkcheck.listeners import disable_listeners
@@ -17,9 +17,9 @@ from ....nominatim_api.nominatim_api_client import NominatimApiClient
 from ....gvz_api.utils import GvzRegion
 from ...constants import status
 from ...models import Region, Page, PageTranslation, LanguageTreeNode
-from ...utils.matomo_api_manager import MatomoException
+from ....matomo_api.matomo_api_client import MatomoException
 from ...utils.slug_utils import generate_unique_slug_helper
-from ...utils.translation_utils import ugettext_many_lazy as __
+from ...utils.translation_utils import gettext_many_lazy as __
 from ..icon_widget import IconWidget
 from ..custom_model_form import CustomModelForm
 
@@ -118,6 +118,7 @@ class RegionForm(CustomModelForm):
             "administrative_division_included",
             "offers",
             "short_urls_enabled",
+            "seo_enabled",
             "custom_prefix",
             "tunews_enabled",
             "timezone",
