@@ -6,11 +6,11 @@ from django.contrib.auth.password_validation import (
     validate_password,
     password_validators_help_texts,
 )
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..custom_model_form import CustomModelForm
 from ...models import Role
-from ...utils.translation_utils import ugettext_many_lazy as __
+from ...utils.translation_utils import gettext_many_lazy as __
 from .organization_field import OrganizationField
 
 logger = logging.getLogger(__name__)
@@ -75,6 +75,7 @@ class UserForm(CustomModelForm):
             "regions",
             "role",
             "send_activation_link",
+            "passwordless_authentication_enabled",
         ]
         field_classes = {"organization": OrganizationField}
 
@@ -111,6 +112,14 @@ class UserForm(CustomModelForm):
             self.fields["is_staff"].label = _("Integreat team member")
         self.fields["email"].required = True
 
+        # Check if passwordless authentication is possible for the user
+        if (
+            "passwordless_authentication_enabled" in self.fields
+            and self.instance.totp_key is None
+            and not self.instance.mfa_keys.exists()
+        ):
+            self.fields["passwordless_authentication_enabled"].disabled = True
+
     def save(self, commit=True):
         """
         This method extends the default ``save()``-method of the base :class:`~django.forms.ModelForm` to set attributes
