@@ -4,7 +4,7 @@ from copy import deepcopy
 
 from django.db import models
 from django.utils.functional import cached_property
-from django.utils.translation import get_language, ugettext_lazy as _
+from django.utils.translation import get_language, gettext_lazy as _
 from django.utils import timezone
 
 from ..constants import status, translation_status
@@ -72,6 +72,19 @@ class ContentQuerySet(models.QuerySet):
             status__in=[status.DRAFT, status.PUBLIC],
         )
 
+    def prefetch_major_translations(self):
+        """
+        Get the queryset including the custom attribute ``prefetched_major_translations`` which contains the
+        latest major (in other words not a minor edit) translations of each content object in each language
+
+        :return: The queryset of content objects
+        :rtype: ~django.db.models.query.QuerySet [ ~integreat_cms.cms.models.abstract_content_model.AbstractContentModel ]
+        """
+        return self.prefetch_translations(
+            to_attr="prefetched_major_translations",
+            minor_edit=False,
+        )
+
     def prefetch_major_public_translations(self):
         """
         Get the queryset including the custom attribute ``prefetched_major_public_translations`` which contains the
@@ -87,6 +100,7 @@ class ContentQuerySet(models.QuerySet):
         )
 
 
+# pylint: disable=too-many-public-methods
 class AbstractContentModel(AbstractBaseModel):
     """
     Abstract base class for all content models
@@ -285,10 +299,9 @@ class AbstractContentModel(AbstractBaseModel):
         :return: The public translation of a content object
         :rtype: ~integreat_cms.cms.models.abstract_content_translation.AbstractContentTranslation
         """
-        translation = self.prefetched_public_or_draft_translations_by_language_slug.get(
+        return self.prefetched_public_or_draft_translations_by_language_slug.get(
             language_slug
         )
-        return translation
 
     @cached_property
     def prefetched_major_public_translations_by_language_slug(self):
@@ -319,6 +332,32 @@ class AbstractContentModel(AbstractBaseModel):
             language_slug
         )
 
+    @cached_property
+    def prefetched_major_translations_by_language_slug(self):
+        """
+        This method returns a mapping from language slugs to their major translations of this object
+
+        :return: The object translation in the requested :class:`~integreat_cms.cms.models.languages.language.Language` or
+                 :obj:`None` if no translation exists
+        :rtype: dict
+        """
+        return self.get_prefetched_translations_by_language_slug(
+            attr="prefetched_major_translations",
+            minor_edit=False,
+        )
+
+    def get_major_translation(self, language_slug):
+        """
+        This function retrieves the newest major translation of a content object.
+
+        :param language_slug: The slug of the requested :class:`~integreat_cms.cms.models.languages.language.Language`
+        :type language_slug: str
+
+        :return: The public translation of a content object
+        :rtype: ~integreat_cms.cms.models.abstract_content_translation.AbstractContentTranslation
+        """
+        return self.prefetched_major_translations_by_language_slug.get(language_slug)
+
     @cached_property
     def backend_translation(self):
         """
@@ -367,10 +406,10 @@ class AbstractContentModel(AbstractBaseModel):
         :return: A string describing the state of the translation, one of :data:`~integreat_cms.cms.constants.translation_status.CHOICES`
         :rtype: str
         """
-        translation = self.get_major_public_translation(language_slug)
+        translation = self.get_translation(language_slug)
         if not translation:
             if self.fallback_translations_enabled:
-                fallback_translation = self.get_public_translation(
+                fallback_translation = self.get_translation(
                     self.region.default_language.slug
                 )
                 if fallback_translation:
