@@ -9,14 +9,14 @@ from django.http import Http404
 from django.utils import timezone as django_timezone
 from django.utils.functional import cached_property
 from django.utils.safestring import mark_safe
-from django.utils.translation import override, ugettext, ugettext_lazy as _
+from django.utils.translation import override, gettext, gettext_lazy as _
 from django.conf import settings
 
 
 from ....nominatim_api.utils import BoundingBox
 from ...constants import region_status, administrative_division
-from ...utils.translation_utils import ugettext_many_lazy as __
-from ...utils.matomo_api_manager import MatomoApiManager
+from ...utils.translation_utils import gettext_many_lazy as __
+from ....matomo_api.matomo_api_client import MatomoApiClient
 from ..abstract_base_model import AbstractBaseModel
 from ..offers.offer_template import OfferTemplate
 
@@ -206,6 +206,13 @@ class Region(AbstractBaseModel):
         verbose_name=_("activate statistics"),
         help_text=_("Whether or not statistics are enabled for the region"),
     )
+    seo_enabled = models.BooleanField(
+        default=False,
+        verbose_name=_("activate SEO section"),
+        help_text=_(
+            "Enable possibility to fill meta description for pages, events and locations"
+        ),
+    )
     matomo_id = models.PositiveSmallIntegerField(
         null=True,
         blank=True,
@@ -509,12 +516,12 @@ class Region(AbstractBaseModel):
     @cached_property
     def statistics(self):
         """
-        This property returns the MatomoApiManager of the current region.
+        This property returns the MatomoApiClient of the current region.
 
         :return: The statistics manager
         :rtype: ~django.db.models.query.QuerySet [ ~django.contrib.auth.models.User ]
         """
-        return MatomoApiManager(self)
+        return MatomoApiClient(self)
 
     def get_language_or_404(self, language_slug, only_active=False, only_visible=False):
         """
@@ -702,10 +709,10 @@ class Region(AbstractBaseModel):
         label = escape(self.full_name)
         if self.status == region_status.HIDDEN:
             # Add warning if region is hidden
-            label += " (&#9888; " + ugettext("Hidden") + ")"
+            label += " (&#9888; " + gettext("Hidden") + ")"
         elif self.status == region_status.ARCHIVED:
             # Add warning if region is archived
-            label += " (&#9888; " + ugettext("Archived") + ")"
+            label += " (&#9888; " + gettext("Archived") + ")"
         # mark as safe so that the warning triangle is not escaped
         return mark_safe(label)
 
