@@ -1,6 +1,7 @@
 """
 This contains tags for accessing settings
 """
+import re
 from django.conf import settings
 from django import template
 
@@ -28,3 +29,16 @@ def get_base_url():
     :rtype: str
     """
     return settings.BASE_URL
+
+
+@register.simple_tag
+def get_internal_urls():
+    """
+    This tag returns the stringified list of url names
+    which should be treated as internal
+
+    :return: stringified list of internal url names
+    :rtype: str
+    """
+    stringified = " ".join(settings.INTERNAL_URLS)
+    return re.sub(r"https?://(www)?", "", stringified)
