@@ -139,6 +139,30 @@ user_settings_urlpatterns = [
         include(
             [
                 path("", settings.UserSettingsView.as_view(), name="user_settings"),
+                path(
+                    "totp/",
+                    include(
+                        [
+                            path(
+                                "",
+                                settings.TOTPRegisterView.as_view(),
+                                name="register_totp",
+                            ),
+                        ]
+                    ),
+                ),
+                path(
+                    "totp/",
+                    include(
+                        [
+                            path(
+                                "delete/",
+                                settings.TOTPDeleteView.as_view(),
+                                name="delete_totp",
+                            ),
+                        ]
+                    ),
+                ),
                 path(
                     "mfa/",
                     include(
@@ -450,11 +474,6 @@ urlpatterns = [
                     utils.search_content_ajax,
                     name="search_content_ajax",
                 ),
-                path(
-                    "get_hix_score/",
-                    utils.get_hix_score,
-                    name="get_hix_score",
-                ),
             ]
         ),
     ),
@@ -567,6 +586,11 @@ urlpatterns = [
                                     ]
                                 ),
                             ),
+                            path(
+                                "get_hix_score/",
+                                utils.get_hix_score,
+                                name="get_hix_score",
+                            ),
                             path(
                                 "statistics/",
                                 include(
@@ -767,7 +791,6 @@ urlpatterns = [
                                             "bulk-archive/",
                                             bulk_action_views.BulkArchiveView.as_view(
                                                 model=Page,
-                                                field_name="explicitly_archived",
                                             ),
                                             name="bulk_archive_pages",
                                         ),
@@ -775,7 +798,6 @@ urlpatterns = [
                                             "bulk-restore/",
                                             bulk_action_views.BulkRestoreView.as_view(
                                                 model=Page,
-                                                field_name="explicitly_archived",
                                             ),
                                             name="bulk_restore_pages",
                                         ),
