@@ -10,7 +10,7 @@ logger = logging.getLogger(__name__)
 
 class LoginView(auth_views.LoginView):
     """
-    View to extend the default login behaviour from :class:`~django.contrib.auth.views.LoginView` with
+    View to extend the default login behavior from :class:`~django.contrib.auth.views.LoginView` with
     multi-factor-authentication.
     """
 
@@ -36,8 +36,16 @@ class LoginView(auth_views.LoginView):
         """
 
         user = form.get_user()
-        if user.mfa_keys.exists():
-            self.request.session["mfa_user_id"] = user.id
-            return redirect("public:login_mfa")
+
+        if not user.passwordless_authentication_enabled:
+
+            if user.mfa_keys.exists():
+                self.request.session["mfa_user_id"] = user.id
+                return redirect("public:login_mfa")
+
+            if user.totp_key:
+                self.request.session["mfa_user_id"] = user.id
+                return redirect("public:login_totp")
+
         auth_login(self.request, form.get_user())
         return redirect(self.get_success_url())
