@@ -1,10 +1,11 @@
 import logging
+
 from django.conf import settings
 from django.contrib import messages
 from django.core.exceptions import PermissionDenied
 from django.shortcuts import render, redirect
 from django.utils.decorators import method_decorator
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.generic import TemplateView
 
 
@@ -12,6 +13,7 @@ from ...constants import status, translation_status
 from ...decorators import permission_required
 from ...forms import EventForm, EventTranslationForm, RecurrenceRuleForm
 from ...models import Language, Event, EventTranslation, RecurrenceRule, POI
+from ...utils.translation_utils import translate_link
 from .event_context_mixin import EventContextMixin
 from ..media.media_context_mixin import MediaContextMixin
 from ..mixins import ContentEditLockMixin
@@ -69,17 +71,6 @@ class EventFormView(
         recurrence_rule_instance = RecurrenceRule.objects.filter(
             event=event_instance
         ).first()
-        if event_instance:
-            poi_instance = event_instance.location
-            initial = {
-                "start_date": event_instance.start_local.date(),
-                "start_time": event_instance.start_local.time(),
-                "end_date": event_instance.end_local.date(),
-                "end_time": event_instance.end_local.time(),
-            }
-        else:
-            poi_instance = None
-            initial = {}
         # Make form disabled if event is archived or user doesn't have the permission to edit the event
         if event_instance and event_instance.archived:
             disabled = True
@@ -103,7 +94,6 @@ class EventFormView(
             )
 
         event_form = EventForm(
-            initial=initial,
             instance=event_instance,
             disabled=disabled,
         )
@@ -122,7 +112,7 @@ class EventFormView(
                 "event_form": event_form,
                 "event_translation_form": event_translation_form,
                 "recurrence_rule_form": recurrence_rule_form,
-                "poi": poi_instance,
+                "poi": event_instance.location if event_instance else None,
                 "language": language,
                 "languages": region.active_languages if event_instance else [language],
                 "url_link": url_link,
@@ -183,6 +173,7 @@ class EventFormView(
             },
             changed_by_user=request.user,
         )
+        user_slug = event_translation_form.data.get("slug")
 
         if (
             not event_form_valid
@@ -224,7 +215,11 @@ class EventFormView(
             # Save event from event form
             event = event_form.save()
             event_translation_form.instance.event = event
-            event_translation_form.save()
+            event_translation_form.save(
+                foreign_form_changed=(
+                    event_form.has_changed() or recurrence_rule_form.has_changed()
+                )
+            )
             # If any source translation changes to draft, set all depending translations/versions to draft
             if event_translation_form.instance.status == status.DRAFT:
                 language_tree_node = region.language_node_by_slug.get(language.slug)
@@ -234,6 +229,39 @@ class EventFormView(
                 event_translation_form.instance.event.translations.filter(
                     language__in=languages
                 ).update(status=status.DRAFT)
+
+            elif (
+                event_translation_form.instance.status == status.PUBLIC
+                and event_translation_form.instance.minor_edit
+            ):
+                event_translation_form.instance.event.translations.filter(
+                    language=language
+                ).update(status=status.PUBLIC)
+            # Show a message that the slug was changed if it was not unique
+            if user_slug and user_slug != event_translation_form.cleaned_data["slug"]:
+                other_translation = EventTranslation.objects.filter(
+                    event__region=region, slug=user_slug, language=language
+                ).first()
+                other_translation_link = other_translation.backend_edit_link
+                message = _(
+                    "The slug was changed from '{user_slug}' to '{slug}', "
+                    "because '{user_slug}' is already used by <a>{translation}</a> or one of its previous versions.",
+                ).format(
+                    user_slug=user_slug,
+                    slug=event_translation_form.cleaned_data["slug"],
+                    translation=other_translation,
+                )
+                messages.warning(
+                    request,
+                    translate_link(
+                        message,
+                        attributes={
+                            "href": other_translation_link,
+                            "class": "underline hover:no-underline",
+                        },
+                    ),
+                )
+
             # Add the success message and redirect to the edit page
             if not event_instance:
                 messages.success(
