@@ -5,7 +5,7 @@ import logging
 
 from django.contrib import messages
 from django.shortcuts import redirect
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.decorators.http import require_POST
 
 from cacheops import invalidate_obj
