@@ -1,6 +1,6 @@
 import logging
 
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.generic.base import ContextMixin
 
 logger = logging.getLogger(__name__)
