@@ -6,7 +6,7 @@ import logging
 from django.db.models import Q, ProtectedError
 from django.http import JsonResponse, HttpResponse
 from django.shortcuts import get_object_or_404
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.decorators.http import require_POST
 
 from ....api.decorators import json_response
