@@ -12,11 +12,10 @@ from django.contrib.auth import get_user_model
 from django.core.exceptions import PermissionDenied
 from django.http import Http404, HttpResponseNotFound, JsonResponse
 from django.shortcuts import render, redirect, get_object_or_404
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.decorators.http import require_POST
 from django.db import transaction
 
-from linkcheck.models import Link
 from treebeard.exceptions import InvalidPosition, InvalidMoveToDescendant
 
 from ....api.decorators import json_response
@@ -51,7 +50,6 @@ def archive_page(request, page_id, region_slug, language_slug):
     :return: A redirection to the :class:`~integreat_cms.cms.views.pages.page_tree_view.PageTreeView`
     :rtype: ~django.http.HttpResponseRedirect
     """
-
     region = request.region
     page = get_object_or_404(region.pages, id=page_id)
 
@@ -60,12 +58,7 @@ def archive_page(request, page_id, region_slug, language_slug):
             f"{request.user!r} does not have the permission to archive {page!r}"
         )
 
-    # Delete related link objects as they are no longer required
-    for child_page in Page.get_tree(parent=page).exclude(explicitly_archived=True):
-        Link.objects.filter(page_translation__page=child_page).delete()
-
-    page.explicitly_archived = True
-    page.save()
+    page.archive()
 
     logger.debug("%r archived by %r", page, request.user)
     messages.success(request, _("Page was successfully archived"))
@@ -110,8 +103,7 @@ def restore_page(request, page_id, region_slug, language_slug):
             f"{request.user!r} does not have the permission to restore {page!r}"
         )
 
-    page.explicitly_archived = False
-    page.save()
+    page.restore()
 
     if page.implicitly_archived:
         logger.debug(
@@ -135,12 +127,6 @@ def restore_page(request, page_id, region_slug, language_slug):
             },
         )
 
-    # Restore related link objects
-    for child_page in Page.get_tree(parent=page).cache_tree(archived=False):
-        for translation in child_page.translations.distinct("page__pk", "language__pk"):
-            # The post_save signal will create link objects from the content
-            translation.save(update_timestamp=False)
-
     logger.debug("%r restored by %r", page, request.user)
     messages.success(request, _("Page was successfully restored."))
     return redirect(
@@ -337,7 +323,7 @@ def cancel_translation_process_ajax(request, region_slug, language_slug, page_id
             status=404,
         )
     page_translation.currently_in_translation = False
-    page_translation.save()
+    page_translation.save(update_timestamp=False)
     # Get new (respectively old) translation state
     translation_state = page.get_translation_state(language_slug)
     return JsonResponse(
