@@ -5,7 +5,7 @@ from django.core.exceptions import PermissionDenied
 from django.shortcuts import render, redirect
 from django.urls import reverse
 from django.utils.decorators import method_decorator
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.generic import TemplateView
 from django.db import transaction
 
@@ -13,7 +13,7 @@ from ...constants import status, text_directions
 from ...decorators import permission_required
 from ...forms import PageForm, PageTranslationForm
 from ...models import PageTranslation
-from ...utils.translation_utils import ugettext_many_lazy as __
+from ...utils.translation_utils import translate_link, gettext_many_lazy as __
 from ..media.media_context_mixin import MediaContextMixin
 from ..mixins import ContentEditLockMixin
 from .page_context_mixin import PageContextMixin
@@ -108,15 +108,18 @@ class PageFormView(
                         action = _("reject")
                     # If the user has the permission to reject/discard, show another message
                     if request.user.has_perm("cms.publish_page_object", page):
-                        status_message = __(
+                        message = __(
                             status_message,
                             _(
-                                "You can {action} these changes in the {link_start}version overview{link_end}."
-                            ).format(
-                                action=action,
-                                link_start=f"<a href='{revision_url}' class='underline hover:no-underline'>",
-                                link_end="</a>",
-                            ),
+                                "You can {action} these changes in the <a>version overview</a>."
+                            ).format(action=action),
+                        )
+                        status_message = translate_link(
+                            message,
+                            attributes={
+                                "href": revision_url,
+                                "class": "underline hover:no-underline",
+                            },
                         )
                     messages.warning(request, status_message)
                 # Show information if a public translation exists even if the latest version is not public
@@ -136,14 +139,17 @@ class PageFormView(
                             "selected_revision": public_translation.version,
                         },
                     )
+                    message = _(
+                        "Currently, <a>version {}</a> of this page is displayed in the app."
+                    ).format(public_translation.version)
                     messages.info(
                         request,
-                        _(
-                            "Currently, {link_start}version {version}{link_end} of this page is displayed in the app."
-                        ).format(
-                            link_start=f" <a href='{revision_url}' class='underline hover:no-underline'>",
-                            version=public_translation.version,
-                            link_end="</a>",
+                        translate_link(
+                            message,
+                            attributes={
+                                "href": revision_url,
+                                "class": "underline hover:no-underline",
+                            },
                         ),
                     )
 
@@ -221,7 +227,7 @@ class PageFormView(
         )
 
     @transaction.atomic
-    # pylint: disable=too-many-branches,unused-argument
+    # pylint: disable=too-many-branches,unused-argument,too-many-statements
     def post(self, request, *args, **kwargs):
         r"""
         Submit :class:`~integreat_cms.cms.forms.pages.page_form.PageForm` and
@@ -286,6 +292,7 @@ class PageFormView(
             },
             changed_by_user=request.user,
         )
+        user_slug = page_translation_form.data.get("slug")
 
         if not page_form.is_valid() or not page_translation_form.is_valid():
             # Add error messages
@@ -316,7 +323,41 @@ class PageFormView(
             ):
                 page_translation_form.instance.page = page_form.save()
             # Save page translation form
-            page_translation_form.save()
+            page_translation_form.save(foreign_form_changed=page_form.has_changed())
+
+            # Show a message that the slug was changed if it was not unique
+            if user_slug and user_slug != page_translation_form.cleaned_data["slug"]:
+                other_translation = PageTranslation.objects.filter(
+                    page__region=region, slug=user_slug, language=language
+                ).first()
+                other_translation_link = reverse(
+                    "page_revisions",
+                    kwargs={
+                        "page_id": other_translation.page.id,
+                        "language_slug": language.slug,
+                        "region_slug": region.slug,
+                        "selected_revision": other_translation.version,
+                    },
+                )
+                message = _(
+                    "The slug was changed from '{user_slug}' to '{slug}', "
+                    "because '{user_slug}' is already used by <a>{translation}</a>.",
+                ).format(
+                    user_slug=user_slug,
+                    slug=page_translation_form.cleaned_data["slug"],
+                    translation=other_translation,
+                )
+                messages.warning(
+                    request,
+                    translate_link(
+                        message,
+                        attributes={
+                            "href": other_translation_link,
+                            "class": "underline hover:no-underline",
+                        },
+                    ),
+                )
+
             # If any source translation changes to draft, set all depending translations/versions to draft
             if page_translation_form.instance.status == status.DRAFT:
                 language_tree_node = region.language_node_by_slug.get(language.slug)
