@@ -7,14 +7,14 @@ from django.conf import settings
 from django.contrib import messages
 from django.shortcuts import render, redirect
 from django.utils.decorators import method_decorator
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.generic import TemplateView
 
 from ...constants import status
 from ...decorators import permission_required
 from ...forms import POIForm, POITranslationForm
 from ...models import POI, POITranslation, Language
-from ...utils.translation_utils import ugettext_many_lazy as __
+from ...utils.translation_utils import translate_link, gettext_many_lazy as __
 from ..media.media_context_mixin import MediaContextMixin
 from ..mixins import ContentEditLockMixin
 from .poi_context_mixin import POIContextMixin
@@ -152,6 +152,7 @@ class POIFormView(
             },
             changed_by_user=request.user,
         )
+        user_slug = poi_translation_form.data.get("slug")
 
         if not poi_form.is_valid() or not poi_translation_form.is_valid():
             # Add error messages
@@ -166,7 +167,7 @@ class POIFormView(
         else:
             # Save forms
             poi_translation_form.instance.poi = poi_form.save()
-            poi_translation_form.save()
+            poi_translation_form.save(foreign_form_changed=poi_form.has_changed())
             # If any source translation changes to draft, set all depending translations/versions to draft
             if poi_translation_form.instance.status == status.DRAFT:
                 language_tree_node = region.language_node_by_slug.get(language.slug)
@@ -176,6 +177,38 @@ class POIFormView(
                 poi_translation_form.instance.poi.translations.filter(
                     language__in=languages
                 ).update(status=status.DRAFT)
+            elif (
+                poi_translation_form.instance.status == status.PUBLIC
+                and poi_translation_form.instance.minor_edit
+            ):
+                poi_translation_form.instance.poi.translations.filter(
+                    language=language
+                ).update(status=status.PUBLIC)
+
+            # Show a message that the slug was changed if it was not unique
+            if user_slug and user_slug != poi_translation_form.cleaned_data["slug"]:
+                other_translation = POITranslation.objects.filter(
+                    poi__region=region, slug=user_slug, language=language
+                ).first()
+                other_translation_link = other_translation.backend_edit_link
+                message = _(
+                    "The slug was changed from '{user_slug}' to '{slug}', "
+                    "because '{user_slug}' is already used by <a>{translation}</a> or one of its previous versions.",
+                ).format(
+                    user_slug=user_slug,
+                    slug=poi_translation_form.cleaned_data["slug"],
+                    translation=other_translation,
+                )
+                messages.warning(
+                    request,
+                    translate_link(
+                        message,
+                        attributes={
+                            "href": other_translation_link,
+                            "class": "underline hover:no-underline",
+                        },
+                    ),
+                )
 
             # Add the success message and redirect to the edit page
             if not poi_instance:
