@@ -5,7 +5,7 @@ import logging
 from django.contrib import messages
 from django.contrib.auth import get_user_model
 from django.shortcuts import get_object_or_404, redirect
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.decorators.http import require_POST
 
 from ...decorators import permission_required
@@ -34,7 +34,9 @@ def delete_user(request, user_id):
     logger.info("%r deleted %r", request.user, user)
     user.delete()
 
-    messages.success(request, _("Account was successfully deleted"))
+    messages.success(
+        request, _('Account "{}" was successfully deleted.').format(user.full_user_name)
+    )
 
     return redirect("users")
 
