@@ -13,7 +13,7 @@ from distutils.util import strtobool
 from urllib.parse import urlparse
 
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..nominatim_api.utils import BoundingBox
 from .logging_formatter import ColorFormatter, RequestFormatter
@@ -44,7 +44,8 @@ MATOMO_TRACKING = bool(
 IMPRINT_SLUG = "imprint"
 
 #: The slug of the region "Testumgebung" - prevent sending PNs to actual users in development in
-#: :func:`~integreat_cms.cms.utils.push_notification_sender.PushNotificationSender.send_pn`
+#: :func:`~integreat_cms.firebase_api.firebase_api_client.FirebaseApiClient.send_pn`
+
 TEST_REGION_SLUG = "testumgebung"
 
 #: URL to the Integreat Website
@@ -114,9 +115,13 @@ DEFAULT_REQUEST_TIMEOUT = int(
     os.environ.get("INTEGREAT_CMS_DEFAULT_REQUEST_TIMEOUT", 10)
 )
 
-###############################
-# Firebase Push Notifications #
-###############################
+
+##############################################################
+# Firebase Push Notifications (Firebase Cloud Messaging FCM) #
+##############################################################
+
+#: FCM API Url
+FCM_URL = "https://fcm.googleapis.com/fcm/send"
 
 #: Authentication token for the Firebase API. This needs to be set for a correct usage of the messages feature.
 FCM_KEY = os.environ.get("INTEGREAT_CMS_FCM_KEY")
@@ -222,8 +227,10 @@ DEBUG = bool(strtobool(os.environ.get("INTEGREAT_CMS_DEBUG", "False")))
 INSTALLED_APPS = [
     # Installed custom apps
     "integreat_cms.cms",
-    "integreat_cms.gvz_api",
     "integreat_cms.deepl_api",
+    "integreat_cms.firebase_api",
+    "integreat_cms.gvz_api",
+    "integreat_cms.matomo_api",
     "integreat_cms.nominatim_api",
     "integreat_cms.summ_ai_api",
     "integreat_cms.textlab_api",
@@ -735,7 +742,7 @@ SUMM_AI_EASY_GERMAN_LANGUAGE_SLUG = os.environ.get(
 SUMM_AI_SEPARATOR = os.environ.get("INTEGREAT_CMS_SUMM_AI_SEPARATOR", "hyphen")
 
 #: All plain text fields of the content models which should be translated
-SUMM_AI_TEXT_FIELDS = ["short_description"]
+SUMM_AI_TEXT_FIELDS = ["meta_description"]
 
 #: All HTML fields of the content models which should be translated
 SUMM_AI_HTML_FIELDS = ["content"]
@@ -867,6 +874,9 @@ LINKCHECK_DISABLE_LISTENERS = bool(
     strtobool(os.environ.get("INTEGREAT_CMS_LINKCHECK_DISABLE_LISTENERS", "False"))
 )
 
+#: The maximum length of URLs which can be checked. Longer URLs will be silently ignored.
+LINKCHECK_MAX_URL_LENGTH = 1024
+
 #: URL types that are not supposed to be shown in the link list (e.g. phone numbers and emails)
 LINKCHECK_IGNORED_URL_TYPES = [
     "mailto",
