@@ -1,4 +1,4 @@
 """
 This package contains all classes for building the webapp's sitemap dynamically.
-It makes use of :doc:`ref/contrib/sitemaps`, an inbuilt Django package.
+It makes use of :doc:`django:ref/contrib/sitemaps`, an inbuilt Django package.
 """
