@@ -1,19 +1,23 @@
 """
 This modules contains the config for the view tests
 """
+import json
+
 from django.conf import settings
 from django.urls import reverse
 
 from integreat_cms.cms.constants import status
+from integreat_cms.cms.models.pois.poi import get_default_opening_hours
 
 from ...conftest import (
     ALL_ROLES,
     AUTHOR,
     EDITOR,
+    OBSERVER,
     HIGH_PRIV_STAFF_ROLES,
     MANAGEMENT,
     PRIV_STAFF_ROLES,
-    REGION_ROLES,
+    WRITE_ROLES,
     ROLES,
     ROOT,
     STAFF_ROLES,
@@ -148,7 +152,7 @@ VIEWS = [
     (
         [
             ("sitemap:region_language", ALL_ROLES),
-            ("archived_pages", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("archived_pages", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
             ("archived_pois", ROLES),
             ("edit_imprint", STAFF_ROLES + [MANAGEMENT]),
             (
@@ -161,7 +165,7 @@ VIEWS = [
             ("new_event", ROLES),
             (
                 "new_event",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {
                     "title": "new event",
                     "start_date": "2030-01-01",
@@ -170,7 +174,7 @@ VIEWS = [
                     "status": status.DRAFT,
                 },
             ),
-            ("new_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("new_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
             (
                 "new_page",
                 PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR],
@@ -196,10 +200,10 @@ VIEWS = [
             ("new_poi", ROLES),
             (
                 "new_poi",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {
                     "title": "new poi",
-                    "short_description": "short description",
+                    "meta_description": "meta description",
                     "address": "Test-Straße 5",
                     "postcode": "54321",
                     "city": "Augsburg",
@@ -207,9 +211,10 @@ VIEWS = [
                     "longitude": 1,
                     "latitude": 1,
                     "status": status.DRAFT,
+                    "opening_hours": json.dumps(get_default_opening_hours()),
                 },
             ),
-            ("pages", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("pages", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
             ("pois", ROLES),
             (
                 "bulk_archive_pages",
@@ -223,28 +228,40 @@ VIEWS = [
             ),
             (
                 "bulk_archive_events",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {"selected_ids[]": [1]},
             ),
             (
                 "bulk_restore_events",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {"selected_ids[]": [1]},
             ),
             (
                 "bulk_archive_pois",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {"selected_ids[]": [4]},
             ),
             (
                 "bulk_restore_pois",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {"selected_ids[]": [4]},
             ),
         ],
         # The kwargs for these views
         {"region_slug": "augsburg", "language_slug": "de"},
     ),
+    (
+        [
+            ("sbs_edit_imprint", STAFF_ROLES + [MANAGEMENT]),
+            (
+                "sbs_edit_imprint",
+                PRIV_STAFF_ROLES + [MANAGEMENT],
+                {"title": "imprint", "status": status.DRAFT},
+            ),
+        ],
+        # The kwargs for these views
+        {"region_slug": "augsburg", "language_slug": "en"},
+    ),
     (
         [
             ("archived_pages", STAFF_ROLES),
@@ -287,7 +304,7 @@ VIEWS = [
                 PRIV_STAFF_ROLES,
                 {
                     "title": "new poi",
-                    "short_description": "short description",
+                    "meta_description": "meta description",
                     "address": "Test-Straße 5",
                     "postcode": "54321",
                     "city": "Augsburg",
@@ -295,6 +312,7 @@ VIEWS = [
                     "longitude": 1,
                     "latitude": 1,
                     "status": status.DRAFT,
+                    "opening_hours": json.dumps(get_default_opening_hours()),
                 },
             ),
             ("pages", STAFF_ROLES),
@@ -431,7 +449,12 @@ VIEWS = [
         {"region_slug": "nurnberg", "url_filter": "invalid"},
     ),
     (
-        [("get_page_order_table_ajax", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR])],
+        [
+            (
+                "get_page_order_table_ajax",
+                STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER],
+            )
+        ],
         # The kwargs for these views
         {"region_slug": "augsburg", "parent_id": 1},
     ),
@@ -555,7 +578,12 @@ VIEWS = [
         {"region_slug": "augsburg", "language_slug": "de", "page_id": 15},
     ),
     (
-        [("get_page_order_table_ajax", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR])],
+        [
+            (
+                "get_page_order_table_ajax",
+                STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER],
+            )
+        ],
         # The kwargs for these views
         {"region_slug": "augsburg", "parent_id": 1, "page_id": 2},
     ),
@@ -565,7 +593,12 @@ VIEWS = [
         {"region_slug": "nurnberg", "parent_id": 7, "page_id": 8},
     ),
     (
-        [("get_page_order_table_ajax", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR])],
+        [
+            (
+                "get_page_order_table_ajax",
+                STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER],
+            )
+        ],
         # The kwargs for these views
         {"region_slug": "augsburg", "page_id": 2},
     ),
@@ -575,7 +608,7 @@ VIEWS = [
         {"region_slug": "nurnberg", "page_id": 8},
     ),
     (
-        [("get_page_tree_ajax", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR])],
+        [("get_page_tree_ajax", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER])],
         # The kwargs for these views
         {"region_slug": "augsburg", "language_slug": "de", "tree_id": 2},
     ),
@@ -586,8 +619,8 @@ VIEWS = [
     ),
     (
         [
-            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
-            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
+            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
             (
                 "edit_page",
                 PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
@@ -632,8 +665,8 @@ VIEWS = [
                     "status": status.PUBLIC,
                 },
             ),
-            ("sbs_edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
-            ("page_revisions", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("sbs_edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
+            ("page_revisions", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
             (
                 "archive_page",
                 PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
@@ -651,8 +684,8 @@ VIEWS = [
     ),
     (
         [
-            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
-            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
+            ("edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
             (
                 "edit_page",
                 PRIV_STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR],
@@ -686,7 +719,7 @@ VIEWS = [
                     "status": status.PUBLIC,
                 },
             ),
-            ("sbs_edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]),
+            ("sbs_edit_page", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]),
         ],
         # The kwargs for these views
         {"region_slug": "augsburg", "language_slug": "en", "page_id": 2},
@@ -721,7 +754,7 @@ VIEWS = [
         },
     ),
     (
-        [("page_revisions", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR])],
+        [("page_revisions", STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER])],
         # The kwargs for these views
         {
             "region_slug": "augsburg",
@@ -735,7 +768,7 @@ VIEWS = [
             ("edit_event", ROLES),
             (
                 "edit_event",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {
                     "title": "new title",
                     "start_date": "2030-01-01",
@@ -744,8 +777,16 @@ VIEWS = [
                     "status": status.DRAFT,
                 },
             ),
-            ("archive_event", PRIV_STAFF_ROLES + REGION_ROLES, {"post_data": True}),
-            ("restore_event", PRIV_STAFF_ROLES + REGION_ROLES, {"post_data": True}),
+            (
+                "archive_event",
+                PRIV_STAFF_ROLES + WRITE_ROLES,
+                {"post_data": True},
+            ),
+            (
+                "restore_event",
+                PRIV_STAFF_ROLES + WRITE_ROLES,
+                {"post_data": True},
+            ),
             ("delete_event", HIGH_PRIV_STAFF_ROLES, {"post_data": True}),
         ],
         # The kwargs for these views
@@ -756,10 +797,10 @@ VIEWS = [
             ("edit_poi", ROLES),
             (
                 "edit_poi",
-                PRIV_STAFF_ROLES + REGION_ROLES,
+                PRIV_STAFF_ROLES + WRITE_ROLES,
                 {
                     "title": "new title",
-                    "short_description": "short description",
+                    "meta_description": "meta description",
                     "address": "Test-Straße 5",
                     "postcode": "54321",
                     "city": "Augsburg",
@@ -767,10 +808,19 @@ VIEWS = [
                     "longitude": 1,
                     "latitude": 1,
                     "status": status.DRAFT,
+                    "opening_hours": json.dumps(get_default_opening_hours()),
                 },
             ),
-            ("archive_poi", PRIV_STAFF_ROLES + REGION_ROLES, {"post_data": True}),
-            ("restore_poi", PRIV_STAFF_ROLES + REGION_ROLES, {"post_data": True}),
+            (
+                "archive_poi",
+                PRIV_STAFF_ROLES + WRITE_ROLES,
+                {"post_data": True},
+            ),
+            (
+                "restore_poi",
+                PRIV_STAFF_ROLES + WRITE_ROLES,
+                {"post_data": True},
+            ),
             ("delete_poi", HIGH_PRIV_STAFF_ROLES, {"post_data": True}),
         ],
         # The kwargs for these views
