@@ -19,6 +19,7 @@ from ..conftest import (
     MANAGEMENT,
     EDITOR,
     AUTHOR,
+    OBSERVER,
 )
 
 
@@ -65,7 +66,7 @@ def test_xliff_export(
         export_xliff, data={"selected_ids[]": [1, 2, 3, 4, 5, 14, 15]}
     )
     print(response.headers)
-    if role in STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR]:
+    if role in STAFF_ROLES + [MANAGEMENT, EDITOR, AUTHOR, OBSERVER]:
         # If the role should be allowed to access the view, we expect a successful result
         assert response.status_code == 302
         page_tree = reverse(
@@ -192,7 +193,7 @@ def test_xliff_import(login_role_user, settings):
                 assert translation.content == "<p>Updated content</p>"
                 assert not translation.currently_in_translation
                 assert (
-                    f'Page "{translation.title}" was imported {msg}.'
+                    f"Page &quot;{translation.title}&quot; was imported {msg}."
                     in response.content.decode("utf-8")
                 )
                 if translation.version > 1:
